@@ -31,6 +31,70 @@ from deepcinac.cinac_structures import create_cinac_recording_from_cinac_file_se
 import sklearn.metrics
 
 
+def select_activity_classifier_on_cell_type_outputs(cell_type_config_file, cell_type_predictions,
+                                                    cell_type_to_classifier, default_classifier,
+                                                    cell_type_threshold=0.5):
+    """
+    Allows to create a dictionary that will be passed to CinacPredictor.add_recording() as the model_files_dict
+    argument. Each cell will be given a specific activity classifier regarding its cell type.
+    Args:
+        cell_type_config_file: yaml file containing the description of the cell classifier, allows
+        to read the cell type predictions
+        cell_type_predictions: np array of 2 dimensions, (n_cells, n_cell_type), value between 0 and 1 predicting
+        if the cell is this cell type
+        cell_type_threshold: use only if binary classifier, if multi_class not used; the cell_type with the maximum
+        prediction is picked.
+        cell_type_to_classifier: (dict), key is the name of a cell type (ex: 'interneuron') it should be in the
+        yaml file, value is tuple of 3 strings (model file, weights file, classifier id) that attribute a
+        specific activity classifier to a cell type
+        default_classifier: (tuple of 3 strings) (model file, weights file, classifier id) that attribute a default
+         activity classifier in a cell has no predominant cell type
+
+    Returns: return a dict compatible with CinacPredictor.add_recording() model_files_dict argument.
+    key is a tuple of 3 strings (model file, weights file, classifier id), and value is the cells whose activity
+    should be classify using this model.
+
+    """
+
+    # TODO: use cell_type_threshold
+
+    model_files_dict = dict()
+
+    cell_type_from_code_dict, cell_type_to_code_dict, multi_class_arg = \
+        read_cell_type_categories_yaml_file(yaml_file=cell_type_config_file)
+
+    # using code instead of string
+    cell_type_to_classifier_encoded = dict()
+    for cell_type, model_tuple in cell_type_to_classifier.items():
+        if cell_type.strip().lower() not in cell_type_to_code_dict:
+            raise Exception(f"Cell type {cell_type} not recognized as a valid cell type, "
+                            f"using {os.path.basename(cell_type_config_file)}")
+        cell_type_code = cell_type_to_code_dict[cell_type.strip().lower()]
+        cell_type_to_classifier_encoded[cell_type_code] = model_tuple
+
+    for cell in np.arange(len(cell_type_predictions)):
+        cell_type_code = np.argmax(cell_type_predictions[cell])
+        if len(np.where(cell_type_predictions[cell] == cell_type_predictions[cell, cell_type_code])[0]) > 1:
+            # mean the cell as two cell types with the same prediction
+            if default_classifier not in model_files_dict:
+                model_files_dict[default_classifier] = []
+            model_files_dict[default_classifier].append(cell)
+        else:
+            if cell_type_code not in cell_type_to_classifier_encoded:
+                raise Exception(f"Cell type code {cell_type_code} not recognized as a valid cell type, "
+                                f"using {os.path.basename(cell_type_config_file)}")
+            model_tuple = cell_type_to_classifier_encoded[cell_type_code]
+            if model_tuple not in model_files_dict:
+                model_files_dict[model_tuple] = []
+            model_files_dict[model_tuple].append(cell)
+
+    # Converting cells list as np.array
+    for model_tuple, cells in model_files_dict.items():
+        model_files_dict[model_tuple] = np.array(cells)
+
+    return model_files_dict
+
+
 class CinacPredictor:
 
     def __init__(self, verbose=0):
@@ -136,8 +200,10 @@ class CinacPredictor:
             n_cells = cinac_recording.get_n_cells()
             n_frames = cinac_recording.get_n_frames()
 
+            network_identifiers = []
             for file_names, cells_to_predict in model_files_dict.items():
                 json_model_file_name, weights_file_name, network_identifier = file_names
+                network_identifiers.append(network_identifier)
                 # ms.tiffs_for_transient_classifier_path = tiffs_for_transient_classifier_path
 
                 if cells_to_predict is None:
@@ -148,6 +214,8 @@ class CinacPredictor:
                     # if cell_type_classifier_mode:
                     #     n_cells = len(cells_to_load)
 
+                print(f"{len(cells_to_load)} cells to predict with {network_identifier}")
+
                 original_cells_to_load = np.copy(cells_to_load)
                 cells_to_load, \
                 original_cell_indices_mapping = self.get_new_cell_indices_if_cells_removed(cells_to_load,
@@ -244,10 +312,10 @@ class CinacPredictor:
                 output_file_formats = [output_file_formats]
 
             # TODO: use all network_identifier if more than one
-            if network_identifier is None:
+            if len(network_identifiers) == 0:
                 network_identifier = ""
             else:
-                network_identifier = "_" + network_identifier
+                network_identifier = "_" + "_".join(network_identifiers)
             if results_path is not None:
                 if create_dir_for_results:
                     time_str = datetime.now().strftime("%Y_%m_%d.%H-%M-%S")
